[hamradio-commits] [dump1090] 181/373: Changing info_footer to info_settings.

Matthew Ernisse mernisse-guest at moszumanska.debian.org
Thu Oct 23 14:58:18 UTC 2014


This is an automated email from the git hooks/post-receive script.

mernisse-guest pushed a commit to branch backport
in repository dump1090.

commit 2d1325f014a20018b4b5bdf0f5758686b05da3be
Author: terribl <terri at rannalla.net>
Date:   Tue May 21 09:47:58 2013 +0300

    Changing info_footer to info_settings.
    
    Location from footer to top right hand corner.
    
    	modified:   public_html/gmap.html
    	modified:   public_html/script.js
    	modified:   public_html/style.css
---
 public_html/gmap.html |  2 +-
 public_html/script.js | 26 +++++++++++---------------
 public_html/style.css |  9 +++------
 3 files changed, 15 insertions(+), 22 deletions(-)

diff --git a/public_html/gmap.html b/public_html/gmap.html
index 78bfd77..a197601 100644
--- a/public_html/gmap.html
+++ b/public_html/gmap.html
@@ -18,7 +18,7 @@
         <p id="selinfo">Click on a plane for info.</p>
         <div id="tabinfo"></div>
       </div>
-      <div id="info_footer"><a href="#" onClick="resetMap();">Reset Map</a></div>
+      <div id="info_settings">[<a href="#" onClick="#resetMap();">Settings</a>]</div>
     </div>
   </body>
 </html>
diff --git a/public_html/style.css b/public_html/style.css
index 72324b2..dd6835f 100644
--- a/public_html/style.css
+++ b/public_html/style.css
@@ -26,12 +26,9 @@ margin:0px;
 margin-top:10px;
 font-size:16px;
 }
-#info_footer {
-position: absolute;
-display: none;
-text-align: center;
-padding:0px;
-margin:0px;
+#info_settings {
+position:   absolute;
+display:    none;
 }
 #tabinfo{
 height: 400px;

diff --git a/public_html/script.js b/public_html/script.js
index 9a3186d..4d6c9fd 100644
--- a/public_html/script.js
+++ b/public_html/script.js
@@ -363,17 +363,12 @@ function printTime() {
     }
 }
 
-function placeFooter() {
-    var windHeight = $(window).height();
-    var footerHeight = $('#info_footer').height();
-    var offset = parseInt(windHeight) - parseInt(footerHeight);
+function placeSettings() {
+    $('#info_settings').css('top', parseInt($('#utcTime').offset().top));
     
-    var footerWidth = parseInt($('#info_footer').width());
-    var infoWidth = parseInt($('#info').width());
-    var marginLeft = parseInt((infoWidth / 2) - (footerWidth / 2));
-    
-    $('#info_footer').css('top', offset);
-    $('#info_footer').css('margin-left', marginLeft);
+    var marginLeft = $('#info').width() - $('#info_settings').width();
+    marginLeft -= parseInt($('#info_settings').width() / 3); // Little air around
+    $('#info_settings').css('left', marginLeft);
 }
 
 function resetMap() {
@@ -381,7 +376,8 @@ function resetMap() {
     localStorage['CenterLon'] = 9.0;
     localStorage['ZoomLvl']   = 5;
     Map.setZoom(parseInt(localStorage['ZoomLvl']));
-    Map.setCenter(new google.maps.LatLng(parseInt(localStorage['CenterLat']), parseInt(localStorage['CenterLon'])));
+    Map.setCenter(new google.maps.LatLng(parseInt(localStorage['CenterLat']),
+            parseInt(localStorage['CenterLon'])));
     Selected = null;
     refreshSelectedInfo();
 }
@@ -413,14 +409,14 @@ function initialize() {
         maxZoom: 18
     }));
     
     // show footer at info-area
     $(function(){
         $(window).resize(function(e){
-            placeFooter();
+            placeSettings();
         });
-        placeFooter();
+        placeSettings();
         // hide it before it's positioned
-        $('#info_footer').css('display','inline');
+        $('#info_settings').css('display','inline');
     });
     
     // Listener for newly created Map
@@ -413,14 +409,14 @@ function initialize() {
     }));
     
-    // show footer at info-area
+    // show settings at info-area
     $(function(){
         $(window).resize(function(e){
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-hamradio/dump1090.git



More information about the pkg-hamradio-commits mailing list